Coordinate class

Geofence Coordinate Data Class

Constructors

Coordinate(String id, String name, double latitude, double longitude, double radius)
Constructor

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
ID of the Geofence.
final
latitude double
Latitude of the Geofence center.
final
longitude double
Longitude of the Geofence center.
final
name String
Name of the Geofence.
final
radius double
Radius of Feofence
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited